Enum RestartPolicy
pub enum RestartPolicy {
Permanent,
OneForOne {
max_restarts: u32,
window: Duration,
},
OneForAll {
max_restarts: u32,
window: Duration,
},
RestForOne {
max_restarts: u32,
window: Duration,
},
}Expand description
Restart policy for supervised actors.
Variants
Permanent
Never restart — if the actor fails, it stays failed.
OneForOne
Restart on failure, up to max_restarts within window.
Fields
OneForAll
Restart the failed actor and all its siblings (children of the same parent).
Fields
RestForOne
Restart the failed actor and all actors that were started after it.