CloudWatchSink

Struct CloudWatchSink 

pub struct CloudWatchSink {
    config: CloudWatchConfig,
    buffer: Mutex<RawMutex, Vec<(u64, String)>>,
    sequence_token: Mutex<RawMutex, Option<String>>,
}
CloudWatch Logs sink for AWS-native audit logging.

When the cloudwatch feature is enabled, this sink uses the AWS SDK to upload audit events to CloudWatch Logs via the PutLogEvents API with automatic batching and retry on throttling.

When the cloudwatch feature is not enabled, this acts as a stub that buffers events but drops them with a warning on flush.

Fields

config: CloudWatchConfigbuffer: Mutex<RawMutex, Vec<(u64, String)>>sequence_token: Mutex<RawMutex, Option<String>>

Implementations



impl CloudWatchSink

pub fn new(config: CloudWatchConfig) -> CloudWatchSink

Create a new CloudWatch Logs sink (stub, without cloudwatch feature).

pub fn config(&self) -> &CloudWatchConfig

Get the configuration.

pub fn buffer_size(&self) -> usize

Get the current buffer size.