ReloadReport

Struct ReloadReport 

pub struct ReloadReport {
    pub rule_id: String,
    pub from_version: u64,
    pub to_version: u64,
    pub quiesce_duration: Duration,
    pub swap_duration: Duration,
    pub messages_in_flight_during_swap: u64,
    pub rollback_available: bool,
}
Report emitted after a successful reload (or rollback).

Fields

rule_id: String

Rule identifier.

from_version: u64

Version we moved away from (0 if this was the initial activation).

to_version: u64

Version that is now Active.

quiesce_duration: Duration

Time spent draining the old actor.

swap_duration: Duration

Time spent performing the atomic pointer swap.

messages_in_flight_during_swap: u64

Messages that were in-flight during the swap window (as reported by the swap backend).

rollback_available: bool

Whether the previous version is still retained in history and can be the target of a subsequent rollback.